Learn R Programming

gyro (version 1.3.0)

PhiMU: Isomorphism from Ungar gyrovector space to Möbius gyrovector space

Description

Isomorphism from the Ungar gyrovector space to the Möbius gyrovector space.

Usage

PhiMU(A, s = 1)

Value

The point of the Poincaré ball of radius s corresponding to A by isomorphism.

Arguments

A

a point in the Ungar vector space with curvature s

s

a positive number, the hyperbolic curvature of the Ungar vector space