Learn R Programming

gyro (version 1.3.0)

gyroABt: Point on a gyroline

Description

Point of coordinate t on the gyroline passing through two given points A and B. This is A for t=0 and this is B for t=1. For t=1/2 this is the gyromidpoint of the gyrosegment joining A and B.

Usage

gyroABt(A, B, t, s = 1, model = "U")

Value

A point.

Arguments

A, B

two distinct points

t

a number

s

positive number, the radius of the Poincaré ball if model="M", otherwise, if model="U", this number defines the hyperbolic curvature

model

the hyperbolic model, either "M" (Möbius model, i.e. Poincaré model) or "U" (Ungar model, i.e. hyperboloid model)