Learn R Programming

gyro (version 1.3.0)

hdelaunay: Hyperbolic Delaunay triangulation

Description

Computes the hyperbolic Delaunay triangulation of a set of points.

Usage

hdelaunay(points, model = "M")

Value

A list with five fields vertices, edges,

triangles, ntriangles, and centroids, a matrix giving the gyrocentroids of the triangles. The input points matrix and the output vertices matrix are the same up to the order of the rows if model="M", and if

model="U", the points in the output vertices matrix are obtained by isomorphism.

Arguments

points

points in the unit disk given as a numeric matrix with two columns

model

the hyperbolic model, either "M" (Möbius model, i.e. Poincaré model) or "U" (Ungar model, i.e. hyperboloid model)

See Also

plotHdelaunay

Examples

Run this code
library(gyro)
library(uniformly)
set.seed(666)
points <- runif_in_sphere(10L, d = 2)
hdelaunay(points)

Run the code above in your browser using DataLab