Some examples of hyperbolic polyhedra realized with the 'gyro'
package.
Usage
gyrodemos()
Arguments
Value
No value. The function firstly copies the demo files in a
temporary directory. If you use RStudio, the function opens these files.
Otherwise it prints a message giving the instructions to access to these
files.