A list with five fields vertices, edges,
triangles, ntriangles, and centroids, a matrix
giving the gyrocentroids of the triangles.
The input points matrix and the output vertices matrix
are the same up to the order of the rows if model="M", and if
model="U", the points in the output vertices matrix are
obtained by isomorphism.